summaryrefslogtreecommitdiff
path: root/libs/ardour/audioengine.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2019-11-04 12:52:34 -0700
committerPaul Davis <paul@linuxaudiosystems.com>2019-11-04 12:52:34 -0700
commit47672fceec568949d8dcf3f2be516a644ff4ccbd (patch)
treefc4c7905e8be973c3cc9c00b705a3ddee0e5771b /libs/ardour/audioengine.cc
parentfd198c373c430b917f0e5e4e3ed6b32fe49b1cc3 (diff)
rename method argument to better reflect its intended role
Diffstat (limited to 'libs/ardour/audioengine.cc')
-rw-r--r--libs/ardour/audioengine.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/libs/ardour/audioengine.cc b/libs/ardour/audioengine.cc
index c7e4efa1d1..a491c9cc35 100644
--- a/libs/ardour/audioengine.cc
+++ b/libs/ardour/audioengine.cc
@@ -142,7 +142,7 @@ AudioEngine::create ()
}
void
-AudioEngine::split_cycle (pframes_t offset)
+AudioEngine::split_cycle (pframes_t nframes)
{
/* caller must hold process lock */
@@ -161,7 +161,7 @@ AudioEngine::split_cycle (pframes_t offset)
* normal processing.
*
* However some non-route ports may contain MIDI events
* from current Port::port_offset() .. Port::port_offset() + offset.
* If those events are not pushed to ports before the cycle split,
* MidiPort::flush_buffers will drop them (event time is out of bounds).
*
@@ -170,10 +170,10 @@ AudioEngine::split_cycle (pframes_t offset)
* all events as-is.
*/
for (Ports::iterator i = p->begin(); i != p->end(); ++i) {
- i->second->flush_buffers (offset);
+ i->second->flush_buffers (nframes);
}
- Port::increment_global_port_buffer_offset (offset);
+ Port::increment_global_port_buffer_offset (nframes);
/* tell all Ports that we're going to start a new (split) cycle */
@@ -161,7 +161,7 @@ AudioEngine::split_cycle (pframes_t offset)
*
* However some non-route ports may contain MIDI events
- * from current Port::port_offset() .. Port::port_offset() + offset.
+ * from current Port::port_offset() .. Port::port_offset() + nframes.
* If those events are not pushed to ports before the cycle split,
* MidiPort::flush_buffers will drop them (event time is out of bounds).